@@ -5,7 +5,7 @@ use warnings;
 
 use Carp ();
 
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 our $PREFIX  = '__cag_';
 our $NEED_COMPAT = 0;
 
@@ -21,7 +21,9 @@ register_types(
     varclass        => {installer => sub { _mk_class_accessor(@_, 1, 0) },  clone_arg => undef},
     varclass_ro     => {installer => sub { _mk_class_accessor(@_, 1, 1) },  clone_arg => undef},
     object          => {installer => sub { _mk_object_accessor(@_, 0) },    clone_arg => 1},
+    accessors       => {installer => sub { _mk_object_accessor(@_, 0) },    clone_arg => 1}, # alias for object
     object_ro       => {installer => sub { _mk_object_accessor(@_, 1) },    clone_arg => 1},
+    getters         => {installer => sub { _mk_object_accessor(@_, 1) },    clone_arg => 1}, # alias for object_ro
     constructor     => {installer => \&_mk_constructor,                     clone_arg => undef},
 );
 
@@ -105,7 +107,9 @@ sub register_type {
     if (!exists $args->{installer}) {
         $args->{installer} = sub {
             my ($class, $name, $field) = @_;
-            install_inherited_cb_accessor("${class}::${name}", $field, $PREFIX.$field, $args->{read_cb}, $args->{write_cb});
+            install_inherited_cb_accessor(
+                "${class}::${name}", $field, $PREFIX.$field, $args->{read_cb} // $args->{on_read}, $args->{write_cb} // $args->{on_write}
+            );
         };
     }
 
@@ -173,6 +177,8 @@ Class::Accessor::Inherited::XS - Fast XS inherited, object and class accessors
       class_ro  => {foo => $default},   # class_ro, varclass_ro, class, varclass set default values instead
       class     => {foo => $subref},    # lazy accessor initializer
       varclass  => ['foo', 'bar'],      # provide a list of accessor names
+      accessors => ['foo'],             # alias for 'object'
+      getters   => ['foo'],             # alias for 'object_ro'
   };
 
   # or at run time, in a Class::Accessor::Grouped-like fashion
